| colMeans2 | R Documentation |
Generic counterpart to matrixStats::colMeans2(). Methods are provided for
delarr objects, but packages can extend the generic for their own delayed
types.
colMeans2(x, ...)
x |
An object for which row means should be computed. |
... |
Additional arguments passed to methods. |
Typically a numeric vector of column means.
mat <- matrix(1:12, nrow = 3, ncol = 4)
darr <- delarr(mat)
# Compute column means lazily
colMeans2(darr)
# Compare with base R
colMeans(mat)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.