Computes the realised dimensions after taking queued slice and reduce operations into account.
Usage
# S3 method for class 'delarr'
dim(x)Computes the realised dimensions after taking queued slice and reduce operations into account.
# S3 method for class 'delarr'
dim(x)